==> ejc-wzxt-impl-3.0.0-20211104.101405-113-sources.jar: com/ejianc/business/wzxt/bean/PickingOutStoreEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.wzxt.bean.PickingOutStoreDetailEntity;
/**
 * 领料出库（主）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_out_store")
public class PickingOutStoreEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 出库单号
    @TableField(value="out_date")
    private java.util.Date outDate; // 出库日期
    @TableField(value="org_id")
    private Long orgId; // 出库组织id
    @TableField(value="org_name")
    private String orgName; // 出库组织名称
    @TableField(value="material_names")
    private String materialNames; // 出库物资名称集合
    @TableField(value="out_num")
    private java.math.BigDecimal outNum; // 出库数量
    @TableField(value="use_for")
    private String useFor; // 用处
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="creator_name")
    private String creatorName; // 编制人
    @TableField(value="creator_time")
    private java.util.Date creatorTime;//编制日期
    @TableField(value="project_name")
    private String projectName; // 出库项目名称
    @TableField(value="project_id")
    private Long projectId; // 出库项目id
    @TableField(value = "project_source_id")
    private String projectSourceId;//项目sourceId
    @TableField(value="picking_unit_id")
    private Long pickingUnitId; // 领料单位id
    @TableField(value="picking_unit_name")
    private String pickingUnitName; // 领料单位名称
    @TableField(value="picking_name")
    private String pickingName; // 领料人名称
    @TableField(value="picking_id")
    private Long pickingId; // 领料人id
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="pickingOutStoreDetailService")
    private List<PickingOutStoreDetailEntity> pickingOutStoreDetailEntities = new ArrayList<>(); // 领料出库（子）
    /**
     * 项目sourceId
     */
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }

    /**
     * 编制日期
     */
    public Date getCreatorTime() {
        return creatorTime;
    }

    public void setCreatorTime(Date creatorTime) {
        this.creatorTime = creatorTime;
    }

    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 出库类型
     */
    /**
     * 出库单号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 出库单号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 出库日期
     */
    public java.util.Date getOutDate() {
        return outDate;
    }

    /**
     * 出库日期
     */
    public void setOutDate(java.util.Date outDate) {
        this.outDate = outDate;
    }
    /**
     * 出库组织id
     */

    public Long getOrgId() {
        return orgId;
    }

    /**
     * 出库组织id
     */

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 出库组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 出库组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 出库物资名称集合
     */
    public String getMaterialNames() {
        return materialNames;
    }

    /**
     * 出库物资名称集合
     */
    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
    /**
     * 出库数量
     */
    public java.math.BigDecimal getOutNum() {
        return outNum;
    }

    /**
     * 出库数量
     */
    public void setOutNum(java.math.BigDecimal outNum) {
        this.outNum = outNum;
    }
    /**
     * 用处
     */
    public String getUseFor() {
        return useFor;
    }

    /**
     * 用处
     */
    public void setUseFor(String useFor) {
        this.useFor = useFor;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 编制人
     */
    public String getCreatorName() {
        return creatorName;
    }

    /**
     * 编制人
     */
    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }
    /**
     * 出库项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 出库项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 出库项目id
     */

    public Long getProjectId() {
        return projectId;
    }

    /**
     * 出库项目id
     */

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 领料单位id
     */
    public Long getPickingUnitId() {
        return pickingUnitId;
    }

    /**
     * 领料单位id
     */

    public void setPickingUnitId(Long pickingUnitId) {
        this.pickingUnitId = pickingUnitId;
    }
    /**
     * 领料单位名称
     */

    public String getPickingUnitName() {
        return pickingUnitName;
    }

    /**
     * 领料单位名称
     */
    public void setPickingUnitName(String pickingUnitName) {
        this.pickingUnitName = pickingUnitName;
    }
    /**
     * 领料人名称
     */
    public String getPickingName() {
        return pickingName;
    }

    /**
     * 领料人名称
     */
    public void setPickingName(String pickingName) {
        this.pickingName = pickingName;
    }
    /**
     * 领料人id
     */
    public Long getPickingId() {
        return pickingId;
    }

    /**
     * 领料人id
     */
    public void setPickingId(Long pickingId) {
        this.pickingId = pickingId;
    }
    
    /**
     * 领料出库（子）
     */
    public List<PickingOutStoreDetailEntity> getPickingOutStoreDetailEntities() {
        return pickingOutStoreDetailEntities;
    }

    /**
     * 领料出库（子）
     */
    public void setPickingOutStoreDetailEntities(List<PickingOutStoreDetailEntity> pickingOutStoreDetailEntities) {
        this.pickingOutStoreDetailEntities = pickingOutStoreDetailEntities;
    }
}

==> ejc-wzxt-impl-3.0.0-20211109.024402-120-sources.jar: com/ejianc/business/wzxt/bean/PickingOutStoreEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.wzxt.bean.PickingOutStoreDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 领料出库（主）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_out_store")
public class PickingOutStoreEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 出库单号
    @TableField(value="out_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date outDate; // 出库日期
    @TableField(value="org_id")
    private Long orgId; // 出库组织id
    @TableField(value="org_name")
    private String orgName; // 出库组织名称
    @TableField(value="material_names")
    private String materialNames; // 出库物资名称集合
    @TableField(value="out_num")
    private java.math.BigDecimal outNum; // 出库数量
    @TableField(value="use_for")
    private String useFor; // 用处
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="creator_name")
    private String creatorName; // 编制人
    @TableField(value="creator_time")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date creatorTime;//编制日期
    @TableField(value="project_name")
    private String projectName; // 出库项目名称
    @TableField(value="project_id")
    private Long projectId; // 出库项目id
    @TableField(value = "project_source_id")
    private String projectSourceId;//项目sourceId
    @TableField(value="picking_unit_id")
    private Long pickingUnitId; // 领料单位id
    @TableField(value="picking_unit_name")
    private String pickingUnitName; // 领料单位名称
    @TableField(value="picking_name")
    private String pickingName; // 领料人名称
    @TableField(value="picking_id")
    private Long pickingId; // 领料人id
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="pickingOutStoreDetailService")
    private List<PickingOutStoreDetailEntity> pickingOutStoreDetailEntities = new ArrayList<>(); // 领料出库（子）
    /**
     * 项目sourceId
     */
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }

    /**
     * 编制日期
     */
    public Date getCreatorTime() {
        return creatorTime;
    }

    public void setCreatorTime(Date creatorTime) {
        this.creatorTime = creatorTime;
    }

    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 出库类型
     */
    /**
     * 出库单号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 出库单号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 出库日期
     */
    public java.util.Date getOutDate() {
        return outDate;
    }

    /**
     * 出库日期
     */
    public void setOutDate(java.util.Date outDate) {
        this.outDate = outDate;
    }
    /**
     * 出库组织id
     */

    public Long getOrgId() {
        return orgId;
    }

    /**
     * 出库组织id
     */

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 出库组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 出库组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 出库物资名称集合
     */
    public String getMaterialNames() {
        return materialNames;
    }

    /**
     * 出库物资名称集合
     */
    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
    /**
     * 出库数量
     */
    public java.math.BigDecimal getOutNum() {
        return outNum;
    }

    /**
     * 出库数量
     */
    public void setOutNum(java.math.BigDecimal outNum) {
        this.outNum = outNum;
    }
    /**
     * 用处
     */
    public String getUseFor() {
        return useFor;
    }

    /**
     * 用处
     */
    public void setUseFor(String useFor) {
        this.useFor = useFor;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 编制人
     */
    public String getCreatorName() {
        return creatorName;
    }

    /**
     * 编制人
     */
    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }
    /**
     * 出库项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 出库项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 出库项目id
     */

    public Long getProjectId() {
        return projectId;
    }

    /**
     * 出库项目id
     */

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 领料单位id
     */
    public Long getPickingUnitId() {
        return pickingUnitId;
    }

    /**
     * 领料单位id
     */

    public void setPickingUnitId(Long pickingUnitId) {
        this.pickingUnitId = pickingUnitId;
    }
    /**
     * 领料单位名称
     */

    public String getPickingUnitName() {
        return pickingUnitName;
    }

    /**
     * 领料单位名称
     */
    public void setPickingUnitName(String pickingUnitName) {
        this.pickingUnitName = pickingUnitName;
    }
    /**
     * 领料人名称
     */
    public String getPickingName() {
        return pickingName;
    }

    /**
     * 领料人名称
     */
    public void setPickingName(String pickingName) {
        this.pickingName = pickingName;
    }
    /**
     * 领料人id
     */
    public Long getPickingId() {
        return pickingId;
    }

    /**
     * 领料人id
     */
    public void setPickingId(Long pickingId) {
        this.pickingId = pickingId;
    }
    
    /**
     * 领料出库（子）
     */
    public List<PickingOutStoreDetailEntity> getPickingOutStoreDetailEntities() {
        return pickingOutStoreDetailEntities;
    }

    /**
     * 领料出库（子）
     */
    public void setPickingOutStoreDetailEntities(List<PickingOutStoreDetailEntity> pickingOutStoreDetailEntities) {
        this.pickingOutStoreDetailEntities = pickingOutStoreDetailEntities;
    }
}
